# History

## 0.7.0 (2020-01-07)

* **Breaking** Be aware of StatusResponse returned from repository

## 0.6.0 (2019-12-31)

* Used nidhoggr-core
* Refactored and cleaned code

## 0.5.0 (2019-12-31)

* Full compatibility with vanilla authlib

## 0.4.0 (2019-12-26)

* **(Breaking)** Drop all texture-related features, except very basic
  ones

## 0.3.0 (2019-12-26)

* Various bugfixes

## 0.2.0 (2019-12-26)

* **(Breaking)** Drop password field from User model

## 0.1.0 (2019-12-26)

* First release on PyPI.
